API for `iadpython` package
===========================

.. automodapi:: iadpython.ad
   :no-inheritance-diagram:

.. automodapi:: iadpython.combine
   :no-inheritance-diagram:

.. automodapi:: iadpython.fresnel
   :no-inheritance-diagram:

.. automodapi:: iadpython.grid
   :no-inheritance-diagram:

.. automodapi:: iadpython.iad
   :no-inheritance-diagram:

..
   .. automodapi:: iadpython.iadc
      :no-inheritance-diagram:

.. automodapi:: iadpython.nist
   :no-inheritance-diagram:

.. automodapi:: iadpython.quadrature
   :no-inheritance-diagram:

.. automodapi:: iadpython.redistribution
   :no-inheritance-diagram:

.. automodapi:: iadpython.sphere
   :no-inheritance-diagram:

.. automodapi:: iadpython.start
   :no-inheritance-diagram:
